[PC-BSD Commits] r5512 - pbibuild/pbi-source/PBIsource
svn at pcbsd.org
svn at pcbsd.org
Wed Dec 9 09:26:14 PST 2009
Author: kris
Date: 2009-12-09 09:26:14 -0800 (Wed, 09 Dec 2009)
New Revision: 5512
Modified:
pbibuild/pbi-source/PBIsource/pbi.cpp
Log:
Fixed a bug determining free space for a target PBI directory
Modified: pbibuild/pbi-source/PBIsource/pbi.cpp
===================================================================
--- pbibuild/pbi-source/PBIsource/pbi.cpp 2009-12-09 14:55:39 UTC (rev 5511)
+++ pbibuild/pbi-source/PBIsource/pbi.cpp 2009-12-09 17:26:14 UTC (rev 5512)
@@ -25,6 +25,7 @@
#include <qlist.h>
#include "pbi.h"
#include "ui_pbi.h"
+#include <QDebug>
using namespace std;
@@ -2024,8 +2025,11 @@
}
// Get our install location
installLoc = lineInstallLocation->text();
+ installLoc.truncate(installLoc.lastIndexOf("/"));
+ installLoc = QDir(installLoc).canonicalPath();
+ qDebug() << "Real install path:" << installLoc;
// Now determine which partition we have selected
i = 0;
More information about the Commits
@@ -2024,8 +2025,11 @@
}
- // Get our install location
+ // Get our install location, the real path
installLoc = lineInstallLocation->text();
mailing list